#ifdef USE_FAST_MALLOC
#include <malloc.h>
#else
#include <stdlib.h>
#endif
#include <stdio.h>
#include <string.h>
#include <math/BAS.h>
#include <math/errorlog.h>
#include <math/memory.h>


Boolean MEM_ObjCreate (void **ptr, size_t size)
/**
    This routine creates a single structure and zeros it out,
      returning a pointer to it.

    Should be freed via MEM_ObjFree() but not Function1()

\param[out] ptr
      Ptr to newly created structure (or NULL if fails)
\param[in] size
      Size of structure
\return
	TRUE if allocation succeeds
  
\author
    J. P. Abelanet - 10/15/95
*/

{
#if MEM_STATISTICS
  MEM_Stats.NumObjectCreations++;
#endif /* MEM_STATISTICS */

  if ((*ptr = malloc (size))) {
    memset (*ptr, 0, size);
    return (TRUE);
  } else
    return (FALSE);
} /* MEM_ObjCreate */


void MEM_ObjFree (void **ptr)
/**
    This routine frees an object allocated with
    MEM_ObjCreate() but not Function1(), and
    NULLs the pointer on return.

\param[in,out] ptr
      Pointer to object to free (can be NULL) -
      will be NULL on return
      
\author
    J. P. Abelanet - 06/20/98
*/

{
#if MEM_STATISTICS
  if (*ptr)
  MEM_Stats.NumObjectFrees++;
#endif /* MEM_STATISTICS */

  free (*ptr);
  *ptr = NULL;
} /* MEM_ObjFree */
